@@ -1,10 +1,9 @@
-mod armor_and_skills;
-mod build_search;
 mod locale;
 mod profile;
 mod style_iced;
 mod ui_iced;
 mod update;
+mod file;
 
 use std::sync::Mutex;
 
