@@ -13,17 +13,19 @@ use std::{
 };
 
 use crate::{
-    armor_and_skills::{
-        get_armor_list, get_talismans, save_talismans_to_file, Armor, Gender, Skill,
-    },
-    build_search::{pre_selection_then_brute_force_search, Build},
-    locale::{get_locales, Locale},
+    file::{get_armor_list, get_talismans, save_talismans_to_file},
+    locale::{get_locales, Locale, LocalizedSkill},
     profile::{get_profile, save_profile},
     style_iced,
     update::download_armors_and_locales,
     ARMORS_PATH, LOCALE_DIR_PATH,
 };
 
+use rab_core::{
+    armor_and_skills::{Armor, Gender, Skill},
+    build_search::{pre_selection_then_brute_force_search, AllArmorSlices, Build},
+};
+
 use iced::{
     button, executor, pick_list, scrollable, slider, text_input, Application, Clipboard, Command,
     Container, Element, Length,
@@ -40,8 +42,8 @@ use self::{
 };
 
 struct WishField {
-    state_pick_list: pick_list::State<Skill>,
-    selected: Skill,
+    state_pick_list: pick_list::State<LocalizedSkill>,
+    selected: LocalizedSkill,
     state_remove_button: button::State,
     state_slider: slider::State,
     value_slider: u8,
@@ -73,8 +75,8 @@ pub struct MainApp {
     state_filter_text_input: text_input::State,
     value_filter_text_input: String,
 
-    sorted_wish_choices: Vec<Skill>,
-    filtered_wish_choices: Vec<Skill>,
+    sorted_wish_choices: Vec<LocalizedSkill>,
+    filtered_wish_choices: Vec<LocalizedSkill>,
 
     helmets: Vec<Armor>,
     chests: Vec<Armor>,
@@ -145,22 +147,24 @@ pub struct MainApp {
     saved_builds: HashMap<String, Build>,
 
     state_builds_menu_button: button::State,
-    states_saved_builds_button: Vec<(
-        button::State,
-        button::State,
-        button::State,
-        button::State,
-        button::State,
-        button::State, //talisman
-        button::State, //weapon
-        button::State, //remove
-    )>,
+    states_saved_builds_button: Vec<SavedBuildsButtonStates>,
     details_build_name: String,
 
     focused_build: Option<Build>,
     total_skills_and_amounts_focused_build: Vec<(Skill, u8)>, // to not sort everytime
 }
 
+type SavedBuildsButtonStates = (
+    button::State,
+    button::State,
+    button::State,
+    button::State,
+    button::State,
+    button::State, //talisman
+    button::State, //weapon
+    button::State, //remove
+);
+
 #[derive(Clone, Copy)]
 enum UpdateState {
     Updating,
@@ -193,7 +197,7 @@ impl Default for Page {
 
 #[derive(Debug, Clone)]
 pub enum Msg {
-    WishSelected(usize, Skill),
+    WishSelected(usize, LocalizedSkill),
     AddWish,
     RemoveWish(usize),
     SliderChanged(usize, u8),
@@ -208,7 +212,7 @@ pub enum Msg {
     CancelEdition,
     TalismanSlotChanged(usize, u8),
     EditTalismanName(String),
-    EditSkillSelected(usize, Skill),
+    EditSkillSelected(usize, LocalizedSkill),
     EditAddSkill,
     EditRemoveSkill(usize),
     EditSkillSliderChanged(usize, u8),
@@ -303,8 +307,7 @@ impl MainApp {
     }
 }
 
-fn get_all_armors_from_file(
-) -> Result<(Vec<Armor>, Vec<Armor>, Vec<Armor>, Vec<Armor>, Vec<Armor>), ron::Error> {
+fn get_all_armors_from_file() -> Result<AllArmors, ron::Error> {
     Ok((
         get_armor_list(HELMETS_PATH)?,
         get_armor_list(CHESTS_PATH)?,
@@ -314,19 +317,19 @@ fn get_all_armors_from_file(
     ))
 }
 
+type AllArmors = (Vec<Armor>, Vec<Armor>, Vec<Armor>, Vec<Armor>, Vec<Armor>);
+
 fn create_locale_and_armors_dir() {
     let armors_path = Path::new(ARMORS_PATH);
     if !armors_path.is_dir() {
-        match fs::create_dir(armors_path) {
-            Err(err) => println!("Can't create armors directory:\n{}", err),
-            _ => {}
+        if let Err(err) = fs::create_dir(armors_path) {
+            println!("Can't create armors directory:\n{}", err)
         }
     }
     let locale_path = Path::new(LOCALE_DIR_PATH);
     if !locale_path.is_dir() {
-        match fs::create_dir(locale_path) {
-            Err(err) => println!("Can't create locale directory:\n{}", err),
-            _ => {}
+        if let Err(err) = fs::create_dir(locale_path) {
+            println!("Can't create locale directory:\n{}", err)
         }
     }
 }
@@ -334,7 +337,7 @@ fn create_locale_and_armors_dir() {
 use lexical_sort::natural_lexical_cmp;
 
 fn save_builds(builds: &HashMap<String, Build>, path: &str) -> Result<String, Error> {
-    let text = to_string_pretty(builds, PrettyConfig::new().with_indentor("  ".to_string()))?;
+    let text = to_string_pretty(builds, PrettyConfig::new().indentor("  ".to_string()))?;
 
     fs::write(path, text)?;
 
@@ -344,7 +347,7 @@ fn save_builds(builds: &HashMap<String, Build>, path: &str) -> Result<String, Er
 }
 
 fn get_saved_builds(path: &str) -> Result<HashMap<String, Build>, Error> {
-    Ok(from_reader(fs::File::open(path)?)?)
+    from_reader(fs::File::open(path)?)
 }
 
 impl Application for MainApp {
@@ -406,7 +409,7 @@ impl Application for MainApp {
         let selected_locale = profile
             .get("lang")
             .cloned()
-            .unwrap_or("English".to_string());
+            .unwrap_or_else(|| "English".to_string());
 
         let theme = match profile.get("theme").unwrap_or(&"dark".to_string()).as_str() {
             "light" => style_iced::Theme::Light,
@@ -417,7 +420,8 @@ impl Application for MainApp {
 
         *super::LOCALE.lock().unwrap() = locales.get(&selected_locale).cloned();
 
-        let mut sorted_wish_choices = Skill::ALL.to_vec();
+        let mut sorted_wish_choices: Vec<LocalizedSkill> =
+            Skill::ALL.iter().map(|s| LocalizedSkill(*s)).collect();
         sorted_wish_choices
             .sort_unstable_by(|a, b| natural_lexical_cmp(&a.to_string(), &b.to_string()));
 
@@ -492,16 +496,18 @@ impl Application for MainApp {
                 let wishes: Vec<(Skill, u8)> = self
                     .wish_fields
                     .iter()
-                    .map(|wish| (wish.selected, wish.value_slider))
+                    .map(|wish| (wish.selected.0, wish.value_slider))
                     .collect();
                 self.builds = pre_selection_then_brute_force_search(
                     &wishes,
-                    &self.helmets,
-                    &self.chests,
-                    &self.arms,
-                    &self.waists,
-                    &self.legs,
-                    &self.talismans,
+                    AllArmorSlices {
+                        helmets: &self.helmets,
+                        chests: &self.chests,
+                        arms: &self.arms,
+                        waists: &self.waists,
+                        legs: &self.legs,
+                        talismans: &self.talismans,
+                    },
                     self.selected_gender,
                     [
                         self.states_values_slider_weapon_slot[0].1,
@@ -539,7 +545,7 @@ impl Application for MainApp {
 
                 for &(skill, amount) in talisman.skills.iter() {
                     self.edit_wish_fields.push(WishField {
-                        selected: skill,
+                        selected: LocalizedSkill(skill),
                         value_slider: amount,
                         ..Default::default()
                     })
@@ -560,7 +566,7 @@ impl Application for MainApp {
                 talisman.skills = self
                     .edit_wish_fields
                     .iter()
-                    .map(|field| (field.selected, field.value_slider))
+                    .map(|field| (field.selected.0, field.value_slider))
                     .collect();
                 talisman.slots = self
                     .states_values_slider_talisman_slot
